<?php

$mgrm_newsletter = new mgrm_newsletter;

class mgrm_newsletter {
	
	var $slug	= "newsletter";
	var $title	= "Newsletter";
	
	var $min_rights		= 'delete_others_pages';
	var $max_rights		= 'activate_plugins';
	
	var $trad	= "";
	
	var $cur_lng	= "";
	
	
	// Construction de la classe
	function __construct()
	{
		$this->trad	= new StdClass();
		
		$this->trad->title		= 'Inscrivez vous à notre newsletter';
		$this->trad->email		= 'Votre adresse email';
		$this->trad->submit		= 'Je m\'inscris';
		
		$this->trad->inscription_confirmation	= 'Nous avons bien enregistré votre inscription.';
		$this->trad->inscription_erreur			= 'Une erreur est survenue lors de votre inscription.';
		$this->trad->inscription_deja_inscrit	= 'Vous êtes déjà inscrit à notre newsletter.';
		
		if ( is_admin() )
		{
			// Ajouter la page d'admin
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_js_css' ) );
			add_action( 'admin_menu', array( $this, 'add_admin_menu' ) );
		}
		
		add_action( 'wp_enqueue_scripts', array( $this, 'front_js_css' ) );
		add_action( 'wp_ajax_front_form_submit', array( $this, 'front_form_submit' ) );
		add_action( 'wp_ajax_nopriv_front_form_submit', array( $this, 'front_form_submit' ) );
	}
	
	// Ajoute le js et css
	function admin_js_css( $current_screen )
	{		
		if ( strstr( $current_screen, '_page_'.$this->slug )  !== false )
		{
			$path = get_template_directory_uri().'/custom/'.$this->slug;
			
			wp_enqueue_style( 'mgrm_'.$this->slug, $path.'/css/admin.css' );
			
			wp_enqueue_script('jquery');
			
			//wp_enqueue_media();
			
			wp_enqueue_script( 'mgrm_'.$this->slug, $path.'/js/admin.js', array('jquery'), null, false );
		}
	}
	
	function add_admin_menu()
	{
		global $mgrm_infos;
		
		add_submenu_page( $mgrm_infos->slug, $this->title, $this->title, $this->min_rights, $this->slug, array( $this, "admin_page" ) );
	}
	
	// Affichage de la page d'admin
	function admin_page()
	{
		$message	= "";
		if ( isset( $_POST['action'] ) && $_POST['action'] == 'update' )
		{
			$message = $this->update_changes();
		}
		
		$data	= get_option( 'mgrm_'.$this->slug );
		$data	= json_decode( $data );
		
		$data_count	= count( $data );
		
		//print "<pre>";
		//print_r( $data );
		//print "</pre>";
		
		?>
		
		<div class="wrap">
			<h2><?php echo $this->title; ?></h2>
			<br>
			<?php echo $message; ?>
			<form action="" method="post">
				<input type="hidden" value="update" name="action">
				
				<table class="widefat">
					<thead>
						<tr>
							<td class="check-column">
								<input class="cb-select-all" type="checkbox" title="<?php echo __( 'Select all' ) ?>">
							</td>
							<td align="left">Adresses email <span class="badge"><?php echo $data_count; ?></span></td>
						</tr>
					</thead>
					<tbody>
						<?php
							$i = 0;
							foreach( $data as $email )
							{
								$alternate	= is_int( $i/2 ) ? ' class="alternate"' : '';
								
								echo '<tr'.$alternate.'><td align="center"><input type="checkbox" name="email-'.$i.'" value="1" title="'.__( 'Remove' ).'" /></td><td>'.$email.'</td></tr>';
								
								$i++;
							}
						?>
					</tbody>
				</table>
				
				<p class="submit"><input id="submit" class="button button-primary" type="submit" value="<?php echo __('Save Changes'); ?>" name="submit"></p>
			</form>
		</div>
		<?php
	}
	
	function update_changes()
	{
		// Récupérer les données
		$data	= get_option( 'mgrm_'.$this->slug );
		$data	= json_decode( $data );
		
		$data_count	= count( $data );
		
		//print "<pre>";
		//print_r( $_POST );
		//print "</pre>";
		
		for ( $i=$data_count; $i>=0; $i-- )
		{
			if ( isset( $_POST['email-'.$i] ) )
			{
				unset( $data[$i] );
			}
		}
		
		sort( $data );
		
		//print "<pre>";
		//print_r( $data );
		//print "</pre>";
		
		$data	= json_encode( $data );
		update_option( 'mgrm_'.$this->slug, $data );
	}
	
	
	function front_js_css()
	{		
		$path = get_template_directory_uri().'/custom/'.$this->slug;
		
		//wp_enqueue_style( 'mgrm_'.$this->slug, $path.'/css/front.css', array(), null );
		wp_enqueue_script( 'mgrm_'.$this->slug, $path.'/js/front.js', array( 'jquery' ), null );
	}
	
	function front_form()
	{
		?>
		<form action="" method="post" id="form-<?php echo $this->slug; ?>">
			<?php wp_nonce_field( 'newsletter-subscription_' . 'form-' . $this->slug );  ?>
			<p class="form-title"><?php echo $this->trad->title; ?></p>
			<div class="input-group">
				<input type="text" class="form-control" name="email" placeholder="<?php echo $this->trad->email; ?>">
				<span class="input-group-btn">
					<button type="submit" class="btn btn-default"><?php echo $this->trad->submit; ?></button>
				</span>
			</div>
			<div class="result"></div>
		</form>
		<?php
	}
	
	function front_form_submit()
	{
		check_admin_referer( 'newsletter-subscription_' . 'form-' . $this->slug );
		
		// Récupérer les données
		$data	= get_option( 'mgrm_'.$this->slug );
		$data	= json_decode( $data );
		
		$email	= sanitize_email( $_POST['email'] );
		
		if ( empty( $data ) )
		{
			$data = array();
		}
		
		if ( !empty( $email ) && !in_array( $email, $data ) )
		{
			array_push( $data, $email );
			
			sort( $data );
			
			$data	= json_encode( $data );
			update_option( 'mgrm_'.$this->slug, $data );
			
			echo '<p>'.$this->trad->inscription_confirmation.'</p>';
			
		}else if (  !empty( $email ) && in_array( $email, $data )  )
		{
			echo '<p>'.$this->trad->inscription_deja_inscrit.'</p>';
			
		}else{
			echo '<p>'.$this->trad->inscription_erreur.'</p>';
		}
		
		die();
	}

}

function mgrm_newsletter_form ()
{
	global $mgrm_newsletter;
	
	echo $mgrm_newsletter->front_form();
}